Module: Stoplight::Domain::_TrafficControl
- Included in:
- TrafficControl::ConsecutiveErrors, TrafficControl::ErrorRate
- Defined in:
- sig/_private/stoplight/domain/ports/traffic_control.rbs
Overview
Strategies for determining when a Stoplight should change color to red.
These strategies evaluate the current state and metrics of a Stoplight to decide if traffic should be stopped (i.e., if the light should turn RED).
Instance Method Summary collapse
-
#== ⇒ Boolean
Object methods.
-
#check_compatibility ⇒ CompatibilityResult
Checks if the strategy is compatible with the given Stoplight configuration.
- #is_a? ⇒ Boolean
-
#stop_traffic? ⇒ Object
Determines whether traffic should be stopped based on the Stoplight's current state and metrics.
Instance Method Details
#== ⇒ Boolean
Object methods
37 |
# File 'sig/_private/stoplight/domain/ports/traffic_control.rbs', line 37
def ==: (untyped) -> bool
|
#check_compatibility ⇒ CompatibilityResult
Checks if the strategy is compatible with the given Stoplight configuration.
29 |
# File 'sig/_private/stoplight/domain/ports/traffic_control.rbs', line 29
def check_compatibility: (Config) -> CompatibilityResult
|
#is_a? ⇒ Boolean
38 |
# File 'sig/_private/stoplight/domain/ports/traffic_control.rbs', line 38
def is_a?: (untyped) -> bool
|
#stop_traffic? ⇒ Object
Determines whether traffic should be stopped based on the Stoplight's current state and metrics.
34 |
# File 'sig/_private/stoplight/domain/ports/traffic_control.rbs', line 34
def stop_traffic?: (Config, Domain::MetricsSnapshot) -> bool
|