Class: Stoplight::Undefined Private
- Inherits:
-
Object
- Object
- Stoplight::Undefined
- Includes:
- Singleton
- Defined in:
- lib/stoplight/undefined.rb,
sig/stoplight/undefined.rbs
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Singleton representing an undefined/not-provided argument.
Distinct from nil, which may be a valid configured value. Used with keyword arguments to detect when a parameter wasn't passed vs. explicitly set to nil.
Class Method Summary collapse
- .instance ⇒ instance private
Instance Method Summary collapse
- #inspect ⇒ String (also: #to_s) private
Class Method Details
.instance ⇒ instance
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5 |
# File 'sig/stoplight/undefined.rbs', line 5
def self.instance: -> instance
|
Instance Method Details
#inspect ⇒ String Also known as: to_s
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
13 |
# File 'lib/stoplight/undefined.rb', line 13 def inspect = "UNDEFINED" |