Class: Stoplight::Wiring::DataStoreBackend Abstract Private
- Inherits:
-
Object
- Object
- Stoplight::Wiring::DataStoreBackend
- Defined in:
- lib/stoplight/wiring/data_store_backend.rb,
sig/_private/stoplight/wiring/data_store_backend.rbs
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Subclass and implement all methods
Abstract base class defining the storage backend interface.
A backend encapsulates all storage construction for a specific data store type (Memory or Redis). Backends handle infrastructure concerns like connection management and failover wrapping, exposing a uniform interface to StorageSetBuilder.
Each method returns a memoized storage instance. Backends are designed to be instantiated once per Light and reused.
Direct Known Subclasses
Instance Method Summary collapse
- #recovery_lock_store ⇒ Domain::_RecoveryLockStore private
- #recovery_metrics_store ⇒ Domain::_MetricsStore private
- #state_store ⇒ Domain::_StateStore private
- #unbounded_metrics_store ⇒ Domain::_MetricsStore private
- #windowed_metrics_store ⇒ Domain::_MetricsStore private
Instance Method Details
#recovery_lock_store ⇒ Domain::_RecoveryLockStore
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
20 |
# File 'lib/stoplight/wiring/data_store_backend.rb', line 20 def recovery_lock_store = raise ArgumentError |
#recovery_metrics_store ⇒ Domain::_MetricsStore
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
21 |
# File 'lib/stoplight/wiring/data_store_backend.rb', line 21 def recovery_metrics_store = raise ArgumentError |
#state_store ⇒ Domain::_StateStore
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
19 |
# File 'lib/stoplight/wiring/data_store_backend.rb', line 19 def state_store = raise ArgumentError |
#unbounded_metrics_store ⇒ Domain::_MetricsStore
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
23 |
# File 'lib/stoplight/wiring/data_store_backend.rb', line 23 def unbounded_metrics_store = raise ArgumentError |
#windowed_metrics_store ⇒ Domain::_MetricsStore
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
22 |
# File 'lib/stoplight/wiring/data_store_backend.rb', line 22 def windowed_metrics_store = raise ArgumentError |